# yt-prompt
A python script that prompts the user to search YouTube, and downloads the selected video(s).


- [SCREENSHOT](#ScreenShot)
- [PREREQUISITES](#Prerequisites)
- [INSTALLATION](#Installation)
- [REQUIRES](#Requires)
- [RUN](#Run)

# ScreenShot:
![yt-promt ScreenShot](/ScreenShot/screen.png?raw=true "yt-prompt Screen Shot")

# Prerequisites:
Python3

# Installation:

    git clone git@github.com:Caraveo/yt-prompt.git

or:

    pip install Youtube-Prompt

# Requires

    pip install yt_dlp

    pip install youtubesearchpython

    pip install ijson

Warning the above commands install the packages [yt_dlp](https://github.com/yt-dlp/yt-dlp), [youtubesearchpython](https://github.com/alexmercerind/youtube-search-python), and [ijson](https://github.com/ICRAR/ijson) system wide.

# Run: 

    cd yt-python

    python app.py


Have fun! :)